"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = __importDefault(require("./logger"));
/**
 * The autoscale poller.
 */
class AutoscalePoller {
    /**
     * Constructs the poller.
     * @param options the options.
     */
    constructor(options) {
        this.pollUrl = options.pollUrl;
        this.statusUrl = options.statusUrl;
        this.statsUrl = options.statsUrl;
        this.instanceDetails = options.instanceDetails;
        this.asapRequest = options.asapRequest;
        this.pollWithStats = this.pollWithStats.bind(this);
    }
    /**
     * Reports stats by sending a json.
     * @param statsReport
     */
    async reportStats(statsReport) {
        try {
            await this.asapRequest.postJson(this.statsUrl, statsReport);
        }
        catch (err) {
            logger_1.default.error('Error sending stats report', { err,
                traceback: err.traceback });
        }
    }
    /**
     * Poll the stats.
     * @param statsReport the stats to report.
     */
    async pollWithStats(statsReport) {
        let body;
        let postURL;
        if (statsReport) {
            // stats are available so use status URL
            body = statsReport;
            postURL = this.statusUrl;
            logger_1.default.debug('Stats report available, sending in request', { body,
                postURL });
        }
        else {
            body = this.instanceDetails;
            postURL = this.pollUrl;
            logger_1.default.debug('Stats report not available, only sending instance info', { body,
                postURL });
        }
        let status = { shutdown: false,
            reconfigure: '' };
        try {
            const response = await this.asapRequest.postJson(postURL, body);
            if (response) {
                status = response;
                logger_1.default.debug('Received response', { status });
                if (status.reconfigure) {
                    logger_1.default.info('Received reconfigure command');
                }
                if (status.shutdown) {
                    logger_1.default.info('Received shutdown command');
                }
            }
        }
        catch (err) {
            logger_1.default.error('Error polling the autoscaler for system status', { err,
                postURL });
        }
        return status;
    }
}
exports.default = AutoscalePoller;
//# sourceMappingURL=autoscale_poller.js.map